@@ -1,5 +1,6 @@
+#line 1 "inc/Module/Install/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.0/Module/Install/PAR.pm"
 # $File: //depot/cpan/Module-Install/lib/Module/Install/PAR.pm $ $Author: autrijus $
-# $Revision: #20 $ $Change: 1376 $ $DateTime: 2003/03/19 04:49:04 $ vim: expandtab shiftwidth=4
+# $Revision: #26 $ $Change: 1555 $ $DateTime: 2003/05/25 11:48:33 $ vim: expandtab shiftwidth=4
 
 package Module::Install::PAR;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -33,11 +34,15 @@ sub par_base {
         $self->{file} = $file = "$name-$version-$suffix";
     }
 
+    my $perl = $^X;
+    $perl = Win32::GetShortPathName($perl)
+        if $perl =~ / / and defined &Win32::GetShortPathName;
+
     $self->preamble(<<"END") if $base;
 # --- $class section:
 
 all ::
-\t\@$^X -M$inc_class -e \"extract_par(q($file))\"
+\t\@$perl -M$inc_class -e \"extract_par(q($file))\"
 
 END
 
@@ -106,19 +111,55 @@ sub make_par {
     my ($self, $file) = @_;
     unlink $file if -f $file;
 
+    my @files;
+    open MANIFEST, ">blib/MANIFEST" or die $!;
+    open META, ">blib/META.yml" or die $!;
+    
+    require File::Find;
+    File::Find::find( sub {
+        (-r && !-d) and push ( @files, substr($File::Find::name, 5) );
+    } , 'blib' );
+
+    print MANIFEST join("\n", '    <!-- accessible as jar:file:///NAME.par!/MANIFEST in compliant browsers -->', (sort @files), q(    # <html><body onload="var X=document.body.innerHTML.split(/\n/);var Y='<iframe src=&quot;META.yml&quot; style=&quot;float:right;height:40%;width:40%&quot;></iframe><ul>';for(var x in X){if(!X[x].match(/^\s*#/)&&X[x].length)Y+='<li><a href=&quot;'+X[x]+'&quot;>'+X[x]+'</a>'}document.body.innerHTML=Y">));
+    close MANIFEST;
+
+    print META << "YAML";
+build_requires: {}
+conflicts: {}
+dist_name: $file
+distribution_type: par
+dynamic_config: 0
+generated_by: 'Module::Install version $Module::Install::VERSION'
+license: unknown
+YAML
+    close META;
+
     if (eval { require Archive::Zip; 1 }) {
         my $zip = Archive::Zip->new;
         $zip->addTree( 'blib', '' );
         $zip->writeToFileNamed( $file ) == AZ_OK or die $!;
     }
     elsif ($self->can_run('zip')) {
-        mkdir('blib');
+        mkdir('blib', 0777);
         chdir('blib');
         system(qw(zip -r), "../$file", '.') and die $!;
         chdir('..');
     }
 
-    print "Successfully created binary distribution '$file'.\n";
+    unlink "blib/MANIFEST";
+    unlink "blib/META.yml";
+
+    require File::Spec;
+    my $pathname = File::Spec->rel2abs($file);
+    if ($^O eq 'MSWin32') {
+        $pathname =~ s!\\!/!g;
+        $pathname =~ s!:!|!g;
+    };
+    print << ".";
+Successfully created binary distribution '$file'.
+Its contents are accessible in compliant browsers as:
+    jar:file://$pathname!/MANIFEST
+.
 }
 
 1;
